require 'spec_helper'

describe Ztodo::Project do

  it 'has methods: init, save and load' do
    methods = [:init!, :save!, :load!]
    methods.each { |method_name| Ztodo::Project.methods.include?(method_name) }
  end

  it 'can add tasks' do
    p = Ztodo::Project.new    
    task = {:key=>'task_A', :priority=>Ztodo::Project::NORMAL,
              :description=>"description for A task", :done=>false} 
    p.add task    
    tasks = p.tasks
    tasks[:task_A].should eq(task)
  end

  it 'can modify tasks' do
    p = Ztodo::Project.new    
    task = {:key=>'task_A', :priority=>Ztodo::Project::NORMAL,
              :description=>"description for A task", :done=>false} 
    task2 = {:key=>'task_B', :priority=>Ztodo::Project::HIGH,
              :description=>"description for B task", :done=>true} 
    p.add task
    p.modify :task_A, task2

    tasks = p.tasks true
    tasks[:task_A].should eq(nil)
    tasks[:task_B].should eq(task2)
  end

  it 'can delete tasks' do
    p = Ztodo::Project.new    
    task = {:key=>'task_A', :priority=>Ztodo::Project::NORMAL,
              :description=>"description for A task", :done=>false}     
    p.add task        
    p.tasks(true)[:task_A].should eq(task)
    p.remove :task_A
    p.tasks(true)[:task_A].should eq(nil)    
  end

  it 'can list uncompleted tasks' do
    p = Ztodo::Project.new
    
    task = {:key=>'task_A', :priority=>Ztodo::Project::NORMAL,
              :description=>"description for A task", :done=>false} 
    task2 = {:key=>'task_B', :priority=>Ztodo::Project::NORMAL,
              :description=>"description for B task", :done=>true} 
    p.add task
    p.add task2

    tasks = p.tasks
    tasks[:task_B].should eq(nil)
    tasks[:task_A].should eq(task)

    tasks = p.tasks true
    tasks.size.should eq(2)
  end

end